Gerrit Dashboards
=================

`Networking-MidoNet Review Inbox <https://review.openstack.org/#/dashboard/?foreach=%28project%3Aopenstack%2Fnetworking-midonet%29+status%3Aopen+NOT+owner%3Aself+NOT+label%3AWorkflow%3C%3D-1+label%3AVerified%3E%3D1%2Cjenkins+NOT+label%3ACode-Review%3E%3D-2%2Cself&title=Networking-MidoNet+Review+Inbox&Needs+Feedback+%28Changes+older+than+5+days+that+have+not+been+reviewed+by+anyone%29=NOT+label%3ACode-Review%3C%3D2+age%3A5d+branch%3Amaster&You+are+a+reviewer%2C+but+haven%27t+voted+in+the+current+revision=reviewer%3Aself+branch%3Amaster&Needs+final+%2B2=label%3ACode-Review%3E%3D2+NOT%28reviewerin%3Anetworking-midonet-core+label%3ACode-Review%3C%3D-1%29+limit%3A50+branch%3Amaster&Passed+Jenkins%2C+No+Negative+Core+Feedback=NOT+label%3ACode-Review%3E%3D2+NOT%28reviewerin%3Anetworking-midonet-core+label%3ACode-Review%3C%3D-1%29+limit%3A50+branch%3Amaster&Wayward+Changes+%28Changes+with+no+code+review+in+the+last+2days%29=NOT+label%3ACode-Review%3C%3D2+age%3A2d+branch%3Amaster&stable%2Fliberty=branch%3Astable%2Fliberty&stable%2Fkilo=branch%3Astable%2Fliberty&other+branches=NOT+branch%3Amaster+AND+NOT+branch%3Astable%2Fliberty+AND+NOT+branch%3Astable%2Fkilo>`_
